using System.Collections.Generic;
using System.Linq;
using System.Threading;
using System.Threading.Tasks;
using Autofac;
using FitConnect.Models;
using FluentAssertions;
using Microsoft.Extensions.Logging;
using MockContainer;
using Newtonsoft.Json;
using NUnit.Framework;

namespace IntegrationTests.Sender;

[TestFixture]
public class ThreadTest {
    private IContainer _container;
    private MockSettings _setting;
    private ILogger _logger;
    private const int NumberOfThreads = 34;

    [SetUp]
    public void Setup() {
        _container = MockContainer.Container.Create();
        _setting = _container.Resolve<MockSettings>();
        _logger = LoggerFactory.Create(b => b.AddConsole())
            .CreateLogger<FitConnect.Sender>();
    }

    [Test]
    [Order(1)]
    public void Test() {
        var tasks = new List<Task>();

        for (int i = 0; i < NumberOfThreads; i++) {
            tasks.Add(Task.Run(() => {
                var counter = Thread.CurrentThread.ManagedThreadId;
                var Sender = new FitConnect.Sender(
                    FitConnectEnvironment.Development,
                    _setting.SenderClientId, _setting.SenderClientSecret, _logger);

                Sender.WithDestination(_setting.DestinationId)
                    .WithServiceType($"ThreadTest_{counter}", _setting.LeikaKey)
                    .WithAttachments(new Attachment("Test.pdf", $"Attachment_{counter}"))
                    .WithData(JsonConvert.SerializeObject(new {
                        Name = $"ThreadTest_{counter}",
                        ThreadId = counter
                    }))
                    .Submit();
            }));
        }

        while (!tasks.All(t => t.IsCompleted)) {
        }
    }

    [Test]
    [Order(2)]
    public void GetSubmissions() {
        var subscriber = FitConnect.Client.GetSubscriber(FitConnectEnvironment.Development,
            _setting.SubscriberClientId, _setting.SubscriberClientSecret,
            _setting.PrivateKeyDecryption, _setting.PrivateKeySigning,
            _setting.PublicKeyEncryption, _setting.PublicKeySignatureVerification, _logger);

        var submissions = subscriber.GetAvailableSubmissions().ToList();

        foreach (var submission in submissions) {
            subscriber
                .RequestSubmission(submission.SubmissionId)
                .AcceptSubmission();
        }

        submissions.Count.Should().Be(NumberOfThreads);
    }
}
